package org.jeecg.modules.ctop.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.modules.ctop.entity.BytedanceFundDaily;
import org.jeecg.modules.ctop.service.IBytedanceFundDailyService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.util.Arrays;

/**
 * 账号日流水信息
 *
 * @author jeecg-boot
 * @version V1.0
 * @date 2020-04-08
 */
@Slf4j
@Api(tags = "账号日流水信息")
@RestController
@RequestMapping("/ctop/bytedanceFundDaily")
public class BytedanceFundDailyController {
    @Autowired
    private IBytedanceFundDailyService bytedanceFundDailyService;

    /**
     * 分页列表查询
     *
     * @param bytedanceFundDaily
     * @param pageNo
     * @param pageSize
     * @param req
     * @return
     */
    @AutoLog(value = "账号日流水信息-分页列表查询")
    @ApiOperation(value = "账号日流水信息-分页列表查询", notes = "账号日流水信息-分页列表查询")
    @GetMapping(value = "/list")
    public Result<IPage<BytedanceFundDaily>> queryPageList(BytedanceFundDaily bytedanceFundDaily,
                                                           @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                                           @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize,
                                                           HttpServletRequest req) {
        Result<IPage<BytedanceFundDaily>> result = new Result<IPage<BytedanceFundDaily>>();
        QueryWrapper<BytedanceFundDaily> queryWrapper = QueryGenerator.initQueryWrapper(bytedanceFundDaily, req.getParameterMap());
        Page<BytedanceFundDaily> page = new Page<BytedanceFundDaily>(pageNo, pageSize);
        IPage<BytedanceFundDaily> pageList = bytedanceFundDailyService.page(page, queryWrapper);
        result.setSuccess(true);
        result.setResult(pageList);
        return result;
    }

    /**
     * 添加
     *
     * @param bytedanceFundDaily
     * @return
     */
    @AutoLog(value = "账号日流水信息-添加")
    @ApiOperation(value = "账号日流水信息-添加", notes = "账号日流水信息-添加")
    @PostMapping(value = "/add")
    public Result<BytedanceFundDaily> add(@RequestBody BytedanceFundDaily bytedanceFundDaily) {
        Result<BytedanceFundDaily> result = new Result<BytedanceFundDaily>();
        try {
            bytedanceFundDailyService.save(bytedanceFundDaily);
            result.success("添加成功！");
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            result.error500("操作失败");
        }
        return result;
    }

    /**
     * 编辑
     *
     * @param bytedanceFundDaily
     * @return
     */
    @AutoLog(value = "账号日流水信息-编辑")
    @ApiOperation(value = "账号日流水信息-编辑", notes = "账号日流水信息-编辑")
    @PutMapping(value = "/edit")
    public Result<BytedanceFundDaily> edit(@RequestBody BytedanceFundDaily bytedanceFundDaily) {
        Result<BytedanceFundDaily> result = new Result<BytedanceFundDaily>();
        BytedanceFundDaily bytedanceFundDailyEntity = bytedanceFundDailyService.getById(bytedanceFundDaily.getId());
        if (bytedanceFundDailyEntity == null) {
            result.error500("未找到对应实体");
        } else {
            boolean ok = bytedanceFundDailyService.updateById(bytedanceFundDaily);
            if (ok) {
                result.success("修改成功!");
            }
        }

        return result;
    }

    /**
     * 通过id删除
     *
     * @param id
     * @return
     */
    @AutoLog(value = "账号日流水信息-通过id删除")
    @ApiOperation(value = "账号日流水信息-通过id删除", notes = "账号日流水信息-通过id删除")
    @DeleteMapping(value = "/delete")
    public Result<?> delete(@RequestParam(name = "id", required = true) String id) {
        try {
            bytedanceFundDailyService.removeById(id);
        } catch (Exception e) {
            log.error("删除失败", e.getMessage());
            return Result.error("删除失败!");
        }
        return Result.ok("删除成功!");
    }

    /**
     * 批量删除
     *
     * @param ids
     * @return
     */
    @AutoLog(value = "账号日流水信息-批量删除")
    @ApiOperation(value = "账号日流水信息-批量删除", notes = "账号日流水信息-批量删除")
    @DeleteMapping(value = "/deleteBatch")
    public Result<BytedanceFundDaily> deleteBatch(@RequestParam(name = "ids", required = true) String ids) {
        Result<BytedanceFundDaily> result = new Result<BytedanceFundDaily>();
        if (ids == null || "".equals(ids.trim())) {
            result.error500("参数不识别！");
        } else {
            this.bytedanceFundDailyService.removeByIds(Arrays.asList(ids.split(",")));
            result.success("删除成功!");
        }
        return result;
    }

    /**
     * 通过id查询
     *
     * @param id
     * @return
     */
    @AutoLog(value = "账号日流水信息-通过id查询")
    @ApiOperation(value = "账号日流水信息-通过id查询", notes = "账号日流水信息-通过id查询")
    @GetMapping(value = "/queryById")
    public Result<BytedanceFundDaily> queryById(@RequestParam(name = "id", required = true) String id) {
        Result<BytedanceFundDaily> result = new Result<BytedanceFundDaily>();
        BytedanceFundDaily bytedanceFundDaily = bytedanceFundDailyService.getById(id);
        if (bytedanceFundDaily == null) {
            result.error500("未找到对应实体");
        } else {
            result.setResult(bytedanceFundDaily);
            result.setSuccess(true);
        }
        return result;
    }
}
