package org.jeecg.modules.ctop.controller;

import com.alibaba.excel.event.AnalysisEventListener;
import com.alibaba.fastjson.JSON;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.ctop.entity.KuaishouChannelRegInfo;
import org.jeecg.modules.ctop.service.IKuaishouChannelRegInfoService;
import org.jeecg.modules.excelutil.ExcelUtils;
import org.jeecg.modules.excelutil.KuaishouChannelRegInfoExcelListener;
import org.jeecg.modules.excelutil.entity.KuaishouChannelRegInfoEntity;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import java.util.Arrays;
import java.util.List;
import java.util.Map;

/**
 * 快手渠道注册信息表
 *
 * @author jeecg-boot
 * @version V1.0
 * @date 2020-03-26
 */
@Slf4j
@Api(tags = "快手渠道注册信息表")
@RestController
@RequestMapping("/ctop/kuaishouChannelRegInfo")
public class KuaishouChannelRegInfoController {
    @Autowired
    private IKuaishouChannelRegInfoService kuaishouChannelRegInfoService;

    /**
     * 分页列表查询
     *
     * @param kuaishouChannelRegInfo
     * @param pageNo
     * @param pageSize
     * @param req
     * @return
     */
    @AutoLog(value = "快手渠道注册信息表-分页列表查询")
    @ApiOperation(value = "快手渠道注册信息表-分页列表查询", notes = "快手渠道注册信息表-分页列表查询")
    @GetMapping(value = "/list")
    public Result<IPage<KuaishouChannelRegInfo>> queryPageList(KuaishouChannelRegInfo kuaishouChannelRegInfo,
                                                               @RequestParam(name = "pageNo", defaultValue = "1") Integer pageNo,
                                                               @RequestParam(name = "pageSize", defaultValue = "10") Integer pageSize,
                                                               HttpServletRequest req) {
        Result<IPage<KuaishouChannelRegInfo>> result = new Result<IPage<KuaishouChannelRegInfo>>();
        QueryWrapper<KuaishouChannelRegInfo> queryWrapper = QueryGenerator.initQueryWrapper(kuaishouChannelRegInfo, req.getParameterMap());
        Page<KuaishouChannelRegInfo> page = new Page<KuaishouChannelRegInfo>(pageNo, pageSize);
        IPage<KuaishouChannelRegInfo> pageList = kuaishouChannelRegInfoService.page(page, queryWrapper);
        result.setSuccess(true);
        result.setResult(pageList);
        return result;
    }

    /**
     * 添加
     *
     * @param kuaishouChannelRegInfo
     * @return
     */
    @AutoLog(value = "快手渠道注册信息表-添加")
    @ApiOperation(value = "快手渠道注册信息表-添加", notes = "快手渠道注册信息表-添加")
    @PostMapping(value = "/add")
    public Result<KuaishouChannelRegInfo> add(@RequestBody KuaishouChannelRegInfo kuaishouChannelRegInfo) {
        Result<KuaishouChannelRegInfo> result = new Result<KuaishouChannelRegInfo>();
        try {
            kuaishouChannelRegInfoService.save(kuaishouChannelRegInfo);
            result.success("添加成功！");
        } catch (Exception e) {
            log.error(e.getMessage(), e);
            result.error500("操作失败");
        }
        return result;
    }

    /**
     * 编辑
     *
     * @param kuaishouChannelRegInfo
     * @return
     */
    @AutoLog(value = "快手渠道注册信息表-编辑")
    @ApiOperation(value = "快手渠道注册信息表-编辑", notes = "快手渠道注册信息表-编辑")
    @PutMapping(value = "/edit")
    public Result<KuaishouChannelRegInfo> edit(@RequestBody KuaishouChannelRegInfo kuaishouChannelRegInfo) {
        Result<KuaishouChannelRegInfo> result = new Result<KuaishouChannelRegInfo>();
        KuaishouChannelRegInfo kuaishouChannelRegInfoEntity = kuaishouChannelRegInfoService.getById(kuaishouChannelRegInfo.getId());
        if (kuaishouChannelRegInfoEntity == null) {
            result.error500("未找到对应实体");
        } else {
            boolean ok = kuaishouChannelRegInfoService.updateById(kuaishouChannelRegInfo);
            if (ok) {
                result.success("修改成功!");
            }
        }

        return result;
    }

    /**
     * 通过id删除
     *
     * @param id
     * @return
     */
    @AutoLog(value = "快手渠道注册信息表-通过id删除")
    @ApiOperation(value = "快手渠道注册信息表-通过id删除", notes = "快手渠道注册信息表-通过id删除")
    @DeleteMapping(value = "/delete")
    public Result<?> delete(@RequestParam(name = "id", required = true) String id) {
        try {
            kuaishouChannelRegInfoService.removeById(id);
        } catch (Exception e) {
            log.error("删除失败", e.getMessage());
            return Result.error("删除失败!");
        }
        return Result.ok("删除成功!");
    }

    /**
     * 批量删除
     *
     * @param ids
     * @return
     */
    @AutoLog(value = "快手渠道注册信息表-批量删除")
    @ApiOperation(value = "快手渠道注册信息表-批量删除", notes = "快手渠道注册信息表-批量删除")
    @DeleteMapping(value = "/deleteBatch")
    public Result<KuaishouChannelRegInfo> deleteBatch(@RequestParam(name = "ids", required = true) String ids) {
        Result<KuaishouChannelRegInfo> result = new Result<KuaishouChannelRegInfo>();
        if (ids == null || "".equals(ids.trim())) {
            result.error500("参数不识别！");
        } else {
            this.kuaishouChannelRegInfoService.removeByIds(Arrays.asList(ids.split(",")));
            result.success("删除成功!");
        }
        return result;
    }

    /**
     * 通过id查询
     *
     * @param id
     * @return
     */
    @AutoLog(value = "快手渠道注册信息表-通过id查询")
    @ApiOperation(value = "快手渠道注册信息表-通过id查询", notes = "快手渠道注册信息表-通过id查询")
    @GetMapping(value = "/queryById")
    public Result<KuaishouChannelRegInfo> queryById(@RequestParam(name = "id", required = true) String id) {
        Result<KuaishouChannelRegInfo> result = new Result<KuaishouChannelRegInfo>();
        KuaishouChannelRegInfo kuaishouChannelRegInfo = kuaishouChannelRegInfoService.getById(id);
        if (kuaishouChannelRegInfo == null) {
            result.error500("未找到对应实体");
        } else {
            result.setResult(kuaishouChannelRegInfo);
            result.setSuccess(true);
        }
        return result;
    }

    /**
     * 导出excel
     *
     * @param request
     * @param response
     */
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, HttpServletResponse response) {
        // Step.1 组装查询条件
        QueryWrapper<KuaishouChannelRegInfo> queryWrapper = null;
        try {
            String paramsStr = request.getParameter("paramsStr");
            if (oConvertUtils.isNotEmpty(paramsStr)) {
                String deString = URLDecoder.decode(paramsStr, "UTF-8");
                KuaishouChannelRegInfo kuaishouChannelRegInfo = JSON.parseObject(deString, KuaishouChannelRegInfo.class);
                queryWrapper = QueryGenerator.initQueryWrapper(kuaishouChannelRegInfo, request.getParameterMap());
            }
        } catch (UnsupportedEncodingException e) {
            e.printStackTrace();
        }

        //Step.2 AutoPoi 导出Excel
        ModelAndView mv = new ModelAndView(new JeecgEntityExcelView());
        List<KuaishouChannelRegInfo> pageList = kuaishouChannelRegInfoService.list(queryWrapper);
        //导出文件名称
        mv.addObject(NormalExcelConstants.FILE_NAME, "快手渠道注册信息表列表");
        mv.addObject(NormalExcelConstants.CLASS, KuaishouChannelRegInfo.class);
        mv.addObject(NormalExcelConstants.PARAMS, new ExportParams("快手渠道注册信息表列表数据", "导出人:Jeecg", "导出信息"));
        mv.addObject(NormalExcelConstants.DATA_LIST, pageList);
        return mv;
    }

    /**
     * 通过excel导入数据
     *
     * @param request
     * @param response
     * @return
     */
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        //1.读Excel
        MultipartHttpServletRequest multipartRequest = (MultipartHttpServletRequest) request;
        Map<String, MultipartFile> fileMap = multipartRequest.getFileMap();
        for (Map.Entry<String, MultipartFile> entity : fileMap.entrySet()) {
            FileInputStream fis = null;
            try {
                MultipartFile file = entity.getValue();
                fis = (FileInputStream) file.getInputStream();
                AnalysisEventListener listener = new KuaishouChannelRegInfoExcelListener();
                Boolean flag = ExcelUtils.readExcel(fis, KuaishouChannelRegInfoEntity.class, listener);
                System.out.println("导入是否成功：" + flag);
            } catch (Exception e) {
                e.printStackTrace();
            } finally {
                if (fis != null) {
                    try {
                        fis.close();
                    } catch (IOException e) {
                        e.printStackTrace();
                    }
                }
            }
        }
        return Result.ok("文件导入成功！");
    }

}
