package cn.com.ctop.bytedance.controller;

import cn.com.ctop.bytedance.service.IBytedanceReportService;
import cn.com.ctop.common.module.entity.CtopOauthToken;
import cn.com.ctop.common.module.service.ICtopOauthTokenService;
import cn.com.ctop.common.module.utils.CtopAdConstant;
import com.alibaba.fastjson.JSONObject;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang.StringUtils;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.util.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.Date;
import java.util.List;

@Slf4j
@RestController
@RequestMapping("/ctop/report")
public class BytedanceReportController {
    @Autowired
    private IBytedanceReportService bytedanceReportService;
    @Autowired
    private ICtopOauthTokenService tokenService;

    /**
     * 昨日总花费
     *
     * @return
     */
    @RequestMapping(value = "/accountReport")
    public Result<JSONObject> getAccountReport() {
        Result<JSONObject> result = new Result<>();

        try {
            JSONObject json = bytedanceReportService.getAccountReport("e9ca23d68d884d4ebb19d07889727dae");
            result.setResult(json);
            result.setSuccess(true);
        } catch (Exception e) {
            e.printStackTrace();
            result.setSuccess(false);
        }

        return result;
    }


    @PostMapping("/kuaiShou/accountReport")
    public Result<JSONObject> getKuaiShouAccountReport(@RequestBody JSONObject requestJson) {
        Result<JSONObject> result = new Result<>();
        try {
            JSONObject json = bytedanceReportService.getKuaiShouAccountReport(requestJson);
            result.setResult(json);
            result.setSuccess(true);
        } catch (Exception e) {
            e.printStackTrace();
            result.setSuccess(false);
        }

        return result;

    }


    @PostMapping("/kuaiShou/accountDetailReport")
    public Result<List<JSONObject>> getKuaiShouAccountDetailReport(@RequestBody JSONObject requestJson) {

        Result<List<JSONObject>> result = new Result<>();
        try {
            List<JSONObject> kuaiShouAccounDetailtReport = bytedanceReportService.getKuaiShouAccounDetailtReport(requestJson);
            result.setResult(kuaiShouAccounDetailtReport);
            result.setSuccess(true);
        } catch (Exception e) {
            e.printStackTrace();
            result.setSuccess(false);
        }

        return result;

    }


    @PostMapping("/kuaiShou/getReportList")
    public Result<List<JSONObject>> getReportList(@RequestBody JSONObject requestJson) {

        Result<List<JSONObject>> result = new Result<>();
        try {
            List<JSONObject> kuaiShouAccounDetailtReport = bytedanceReportService.getReportList(requestJson);
            result.setResult(kuaiShouAccounDetailtReport);
            result.setSuccess(true);
        } catch (Exception e) {
            e.printStackTrace();
            result.setSuccess(false);

        }
        return result;

    }

    @PostMapping("/bytedance/async")
    public Result<List<JSONObject>> asyncTaskCreate(@RequestBody JSONObject requestJson) {

        Result<List<JSONObject>> result = new Result<>();
        try {
            bytedanceReportService.bytedanceAsyncTaskCreate();

        } catch (Exception e) {
            e.printStackTrace();
            result.setSuccess(false);
        }
        return result;

    }

    @PostMapping("/bytedance/async/taskGet")
    public Result<List<JSONObject>> bytedanceAsyncTaskGet(@RequestBody JSONObject requestJson) {
        Result<List<JSONObject>> result = new Result<>();
        try {
            bytedanceReportService.bytedanceAsyncTaskGet();
        } catch (Exception e) {
            e.printStackTrace();
            result.setSuccess(false);
        }
        return result;
    }

    @GetMapping("/bytedance/bytedanceMaterialReport")
    public Result bytedanceMaterialReport(@RequestParam(name = "startDate")String startDate,
                                                            @RequestParam(name = "endDate")String endDate) {
        Result result = new Result<>();
        if (StringUtils.isBlank(startDate) || StringUtils.isBlank(endDate)){
            result.error500("开始时间和结束时间不能为空");
            return result;
        }

        try {
            log.info("头条获取素材报表数据任务执行开始");
            Long start = System.currentTimeMillis();
            List<CtopOauthToken> tokens = tokenService.selectToutiaoToken();
            if (null == tokens || tokens.size() <= 0) {
                log.info("头条获取素材报表数据任务执行失败:未获取到可用的token");
                return result;
            }
            for (CtopOauthToken token : tokens) {
                //if(token.getAccountId() == 1647352267707396L){
                    bytedanceReportService.bytedanceMaterialReport(token,startDate,endDate);
                //}
            }
            Long end = System.currentTimeMillis();
            log.info("头条获取素材报表数据任务执行结束,执行耗时：{}秒", (end - start) / 1000);
        } catch (Exception e) {
            log.error("头条获取素材报表数据任务执行结失败");
            e.printStackTrace();
            result.setSuccess(false);
        }
        return result;
    }

}
